@@ -173,22 +173,34 @@ class ConstanceAdmin(admin.ModelAdmin):
         config_value = {
             'name': name,
             'default': localize(default),
+            'raw_default': default,
             'help_text': _(help_text),
             'value': localize(value),
             'modified': localize(value) != localize(default),
             'form_field': form[name],
+            'is_checkbox': isinstance(
+                form[name].field.widget, forms.CheckboxInput),
         }
 
         return config_value
 
+    def get_changelist_form(self, request):
+        """
+        Returns a Form class for use in the changelist_view.
+        """
+        # Defaults to self.change_list_form in order to preserve backward
+        # compatibility
+        return self.change_list_form
+
     @csrf_protect_m
     def changelist_view(self, request, extra_context=None):
         if not self.has_change_permission(request, None):
             raise PermissionDenied
         initial = get_values()
-        form = self.change_list_form(initial=initial)
+        form_cls = self.get_changelist_form(request)
+        form = form_cls(initial=initial)
         if request.method == 'POST':
-            form = self.change_list_form(data=request.POST, initial=initial)
+            form = form_cls(data=request.POST, initial=initial)
             if form.is_valid():
                 form.save()
                 messages.add_message(
