@@ -48,7 +48,8 @@ class RedisBackend(Backend):
                 yield key, loads(value)
 
     def set(self, key, value):
+        old_value = self.get(key)
         self._rd.set(self.add_prefix(key), dumps(value))
         signals.config_updated.send(
-            sender=config, updated_key=key, new_value=value
+            sender=config, key=key, old_value=old_value, new_value=value
         )
